WrappedPlayer class

Constructors

WrappedPlayer(String playerId)

Properties

balance ← double
no getter
eventStreamController → StreamController<AudioEvent>
final
hashCode → int
The hash code for this object.
no setterinherited
playbackRate ← double
no getter
player ↔ HTMLAudioElement?
getter/setter pair
playerId → String
final
releaseMode ← ReleaseMode
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volume ← double
no getter

Methods

dispose() → Future<void>
log(String message) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
recreateNode() → void
release() → Future<void>
resume() → Future<void>
seek(int position) → void
setUrl(String url) → Future<void>
shouldLoop() → bool
start(double position) → Future<void>
stop() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited